#!/usr/bin/perl


$filename = $ARGV[0];
open (MAPLIST, $filename) || die "Failed to open $filename";

while (<MAPLIST>) {
	($langlist, $name, $english) = split;
	print "# $filename, $name\n";
	print "msgid \"$english\"\n";
	print "msgstr \"\"\n\n";
}

close MAPLIST;
