#!/usr/bin/perl


open (MAPLIST, $ARGV[0]) || die "Failed to open $ARGV[0]\n";

print "Template: $ARGV[0]/keymap\n";
print "Type: select\n";

$keymaps = "";

while (<MAPLIST>) {
	($langs,$name,$english) = split ;
	if ($keymaps eq "") { 
		$keymaps = $name;
	} else {
		$keymaps = join (', ', $keymaps, $name);
	}		
}

print "__Choices: $keymaps\n";
